@@ -1,11 +1,11 @@
 package UNIVERSAL::Object::ID;
 
-use 5.8.8;
+use 5.008_008;
 
 use strict;
 use warnings;
 
-use version; our $VERSION = qv("v0.1.1");
+use version; our $VERSION = qv("v0.1.2");
 
 {
     package UNIVERSAL;
